@@ -68,8 +68,8 @@ Device::Device(QObject* parent, const QString& id)
 
 Device::Device(QObject* parent, const NetworkPackage& identityPackage, DeviceLink* dl)
     : QObject(parent)
-    , m_deviceId(identityPackage.get<QString>("deviceId"))
-    , m_deviceName(identityPackage.get<QString>("deviceName"))
+    , m_deviceId(identityPackage.get<QString>(QStringLiteral("deviceId")))
+    , m_deviceName(identityPackage.get<QString>(QStringLiteral("deviceName")))
 {
     addLink(identityPackage, dl);
 
@@ -108,7 +108,7 @@ void Device::reloadPlugins()
             const KPluginMetaData service = loader->getPluginInfo(pluginName);
 
             const bool pluginEnabled = isPluginEnabled(pluginName);
-            const QSet<QString> incomingCapabilities = KPluginMetaData::readStringList(service.rawData(), "X-KdeConnect-SupportedPackageType").toSet();
+            const QSet<QString> incomingCapabilities = KPluginMetaData::readStringList(service.rawData(), QStringLiteral("X-KdeConnect-SupportedPackageType")).toSet();
 
             if (pluginEnabled) {
                 KdeConnectPlugin* plugin = m_plugins.take(pluginName);
@@ -146,7 +146,7 @@ void Device::reloadPlugins()
 
 QString Device::pluginsConfigFile() const
 {
-    return KdeConnectConfig::instance()->deviceConfigDir(id()).absoluteFilePath("config");
+    return KdeConnectConfig::instance()->deviceConfigDir(id()).absoluteFilePath(QStringLiteral("config"));
 }
 
 void Device::requestPair()
@@ -206,33 +206,33 @@ void Device::addLink(const NetworkPackage& identityPackage, DeviceLink* link)
 
     Q_ASSERT(!m_deviceLinks.contains(link));
 
-    m_protocolVersion = identityPackage.get<int>("protocolVersion", -1);
+    m_protocolVersion = identityPackage.get<int>(QStringLiteral("protocolVersion"), -1);
     if (m_protocolVersion != NetworkPackage::ProtocolVersion) {
         qCWarning(KDECONNECT_CORE) << m_deviceName << "- warning, device uses a different protocol version" << m_protocolVersion << "expected" << NetworkPackage::ProtocolVersion;
     }
 
-    connect(link, SIGNAL(destroyed(QObject*)),
-            this, SLOT(linkDestroyed(QObject*)));
+    connect(link, &QObject::destroyed,
+            this, &Device::linkDestroyed);
 
     m_deviceLinks.append(link);
 
     //re-read the device name from the identityPackage because it could have changed
-    setName(identityPackage.get<QString>("deviceName"));
-    m_deviceType = str2type(identityPackage.get<QString>("deviceType"));
+    setName(identityPackage.get<QString>(QStringLiteral("deviceName")));
+    m_deviceType = str2type(identityPackage.get<QString>(QStringLiteral("deviceType")));
 
     //Theoretically we will never add two links from the same provider (the provider should destroy
     //the old one before this is called), so we do not have to worry about destroying old links.
     //-- Actually, we should not destroy them or the provider will store an invalid ref!
 
-    connect(link, SIGNAL(receivedPackage(NetworkPackage)),
-            this, SLOT(privateReceivedPackage(NetworkPackage)));
+    connect(link, &DeviceLink::receivedPackage,
+            this, &Device::privateReceivedPackage);
 
     qSort(m_deviceLinks.begin(), m_deviceLinks.end(), lessThan);
 
-    const bool capabilitiesSupported = identityPackage.has("incomingCapabilities") || identityPackage.has("outgoingCapabilities");
+    const bool capabilitiesSupported = identityPackage.has(QStringLiteral("incomingCapabilities")) || identityPackage.has(QStringLiteral("outgoingCapabilities"));
     if (capabilitiesSupported) {
-        const QSet<QString> outgoingCapabilities = identityPackage.get<QStringList>("outgoingCapabilities").toSet()
-                          , incomingCapabilities = identityPackage.get<QStringList>("incomingCapabilities").toSet();
+        const QSet<QString> outgoingCapabilities = identityPackage.get<QStringList>(QStringLiteral("outgoingCapabilities")).toSet()
+                          , incomingCapabilities = identityPackage.get<QStringList>(QStringLiteral("incomingCapabilities")).toSet();
 
         m_supportedPlugins = PluginLoader::instance()->pluginsForCapabilities(incomingCapabilities, outgoingCapabilities);
         //qDebug() << "new plugins for" << m_deviceName << m_supportedPlugins << incomingCapabilities << outgoingCapabilities;
@@ -306,6 +306,7 @@ bool Device::isTrusted() const
 QStringList Device::availableLinks() const
 {
     QStringList sl;
+    sl.reserve(m_deviceLinks.size());
     Q_FOREACH(DeviceLink* dl, m_deviceLinks) {
         sl.append(dl->provider()->name());
     }
@@ -328,19 +329,19 @@ void Device::cleanUnneededLinks() {
 }
 
 Device::DeviceType Device::str2type(const QString &deviceType) {
-    if (deviceType == "desktop") return Desktop;
-    if (deviceType == "laptop") return Laptop;
-    if (deviceType == "smartphone" || deviceType == "phone") return Phone;
-    if (deviceType == "tablet") return Tablet;
+    if (deviceType == QLatin1String("desktop")) return Desktop;
+    if (deviceType == QLatin1String("laptop")) return Laptop;
+    if (deviceType == QLatin1String("smartphone") || deviceType == QLatin1String("phone")) return Phone;
+    if (deviceType == QLatin1String("tablet")) return Tablet;
     return Unknown;
 }
 
 QString Device::type2str(Device::DeviceType deviceType) {
-    if (deviceType == Desktop) return "desktop";
-    if (deviceType == Laptop) return "laptop";
-    if (deviceType == Phone) return "smartphone";
-    if (deviceType == Tablet) return "tablet";
-    return "unknown";
+    if (deviceType == Desktop) return QStringLiteral("desktop");
+    if (deviceType == Laptop) return QStringLiteral("laptop");
+    if (deviceType == Phone) return QStringLiteral("smartphone");
+    if (deviceType == Tablet) return QStringLiteral("tablet");
+    return QStringLiteral("unknown");
 }
 
 QString Device::statusIconName() const
@@ -406,15 +407,15 @@ QString Device::encryptionInfo() const
     QCryptographicHash::Algorithm digestAlgorithm = QCryptographicHash::Algorithm::Sha1;
 
     QString localSha1 = QString::fromLatin1(KdeConnectConfig::instance()->certificate().digest(digestAlgorithm).toHex());
-    for (int i=2 ; i<localSha1.size() ; i+=3) {
+    for (int i = 2; i<localSha1.size(); i += 3) {
         localSha1.insert(i, ':'); // Improve readability
     }
     result += i18n("SHA1 fingerprint of your device certificate is: %1\n", localSha1);
 
-    std::string  remotePem = KdeConnectConfig::instance()->getDeviceProperty(id(), "certificate").toStdString();
-    QSslCertificate remoteCertificate = QSslCertificate(QByteArray(remotePem.c_str(), remotePem.size()));
+    std::string  remotePem = KdeConnectConfig::instance()->getDeviceProperty(id(), QStringLiteral("certificate")).toStdString();
+    QSslCertificate remoteCertificate = QSslCertificate(QByteArray(remotePem.c_str(), (int)remotePem.size()));
     QString remoteSha1 = QString::fromLatin1(remoteCertificate.digest(digestAlgorithm).toHex());
-    for (int i=2 ; i<remoteSha1.size() ; i+=3) {
+    for (int i = 2; i < remoteSha1.size(); i += 3) {
         remoteSha1.insert(i, ':'); // Improve readability
     }
     result += i18n("SHA1 fingerprint of remote device certificate is: %1\n", remoteSha1);
