@@ -33,7 +33,7 @@ FileTransferJob::FileTransferJob(const QSharedPointer<QIODevice>& origin, qint64
     : KJob()
     , mOrigin(origin)
     , mReply(Q_NULLPTR)
-    , mFrom("KDE Connect")
+    , mFrom(QStringLiteral("KDE Connect"))
     , mDestination(destination)
     , mSpeedBytes(0)
     , mWritten(0)
@@ -42,7 +42,7 @@ FileTransferJob::FileTransferJob(const QSharedPointer<QIODevice>& origin, qint64
     Q_ASSERT(mOrigin->isReadable());
     if (mDestination.scheme().isEmpty()) {
         qCWarning(KDECONNECT_CORE) << "Destination QUrl" << mDestination << "lacks a scheme. Setting its scheme to 'file'.";
-        mDestination.setScheme("file");
+        mDestination.setScheme(QStringLiteral("file"));
     }
 
     if (size >= 0) {
@@ -80,7 +80,7 @@ void FileTransferJob::doStart()
 void FileTransferJob::startTransfer()
 {
     setProcessedAmount(Bytes, 0);
-    mTime = QTime::currentTime();
+    mTimer.start();
     description(this, i18n("Receiving file over KDE Connect"),
                         { i18nc("File transfer origin", "From"), mFrom },
                         { i18nc("File transfer destination", "To"), mDestination.toLocalFile() });
@@ -91,7 +91,11 @@ void FileTransferJob::startTransfer()
 
     connect(mReply, &QNetworkReply::uploadProgress, this, [this](qint64 bytesSent, qint64 /*bytesTotal*/) {
         setProcessedAmount(Bytes, bytesSent);
-        emitSpeed(bytesSent/mTime.elapsed());
+
+        const auto elapsed = mTimer.elapsed();
+        if (elapsed > 0) {
+            emitSpeed(bytesSent / elapsed);
+        }
     });
     connect(mReply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error),
             this, &FileTransferJob::transferFailed);
