@@ -90,18 +90,18 @@ void KioKdeconnect::listAllDevices()
 
         DeviceDbusInterface interface(deviceId);
 
-        if (!interface.hasPlugin("kdeconnect_sftp")) continue;
+        if (!interface.hasPlugin(QStringLiteral("kdeconnect_sftp"))) continue;
 
-        const QString path = QString("kdeconnect://").append(deviceId).append("/");
+        const QString path = QStringLiteral("kdeconnect://").append(deviceId).append("/");
         const QString name = interface.name();
-        const QString icon = "kdeconnect";
+        const QString icon = QStringLiteral("kdeconnect");
 
         KIO::UDSEntry entry;
         entry.insert(KIO::UDSEntry::UDS_NAME, name);
         entry.insert(KIO::UDSEntry::UDS_ICON_NAME, icon);
         entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
         entry.insert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
-        entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, "");
+        entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QLatin1String(""));
         entry.insert(KIO::UDSEntry::UDS_URL, path);
         listEntry(entry);
     }
@@ -114,7 +114,7 @@ void KioKdeconnect::listAllDevices()
     entry.insert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IWGRP | S_IXGRP | S_IROTH | S_IXOTH);
     listEntry(entry);
 
-    infoMessage("");
+    infoMessage(QLatin1String(""));
     finished();
 }
 
@@ -149,15 +149,15 @@ void KioKdeconnect::listDevice()
 
         const QString path = it.key();
         const QString name = it.value().toString();
-        const QString icon = QLatin1Literal("folder");
+        const QString icon = QStringLiteral("folder");
 
         KIO::UDSEntry entry;
-        entry.insert(KIO::UDSEntry::UDS_NAME, "files");
+        entry.insert(KIO::UDSEntry::UDS_NAME, QStringLiteral("files"));
         entry.insert(KIO::UDSEntry::UDS_DISPLAY_NAME, name);
         entry.insert(KIO::UDSEntry::UDS_ICON_NAME, icon);
         entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
         entry.insert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
-        entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, "");
+        entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QLatin1String(""));
         entry.insert(KIO::UDSEntry::UDS_URL, QUrl::fromLocalFile(path).toString());
         listEntry(entry);
     }
@@ -170,7 +170,7 @@ void KioKdeconnect::listDevice()
     entry.insert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IWGRP | S_IXGRP | S_IROTH | S_IXOTH);
     listEntry(entry);
 
-    infoMessage("");
+    infoMessage(QLatin1String(""));
     finished();
 
 }
@@ -212,7 +212,7 @@ void KioKdeconnect::stat(const QUrl &url)
 void KioKdeconnect::get(const QUrl &url)
 {
     qCDebug(KDECONNECT_KIO) << "Get: " << url;
-    mimeType("");
+    mimeType(QLatin1String(""));
     finished();
 }
 
