@@ -27,7 +27,7 @@
 #include <core/kdeconnectplugin.h>
 
 Q_DECLARE_LOGGING_CATEGORY(KDECONNECT_PLUGIN_CLIPBOARD)
-#define PACKAGE_TYPE_CLIPBOARD QLatin1String("kdeconnect.clipboard")
+#define PACKAGE_TYPE_CLIPBOARD QStringLiteral("kdeconnect.clipboard")
 
 class ClipboardPlugin
     : public KdeConnectPlugin
@@ -42,11 +42,8 @@ public Q_SLOTS:
     void connected() override { }
     
 private Q_SLOTS:
-    void clipboardChanged(QClipboard::Mode mode);
+    void propagateClipboard(const QString& content);
 
-private:
-    QString currentContent;
-    QClipboard *clipboard;
 };
 
 #endif
