@@ -19,27 +19,21 @@
  */
 
 #include "pausemusic_config.h"
-
-#include <KPluginFactory>
-#include <KSharedConfig>
-#include <KConfigGroup>
-
-#include <core/kdebugnamespace.h>
-
 #include "ui_pausemusic_config.h"
 
-K_PLUGIN_FACTORY(PauseMusicConfigFactory, registerPlugin<PauseMusicConfig>();)
-K_EXPORT_PLUGIN(PauseMusicConfigFactory("kdeconnect_pausemusic_config", "kdeconnect-kded"))
+#include <KPluginFactory>
 
-PauseMusicConfig::PauseMusicConfig(QWidget *parent, const QVariantList& )
-    : KCModule(PauseMusicConfigFactory::componentData(), parent)
+K_PLUGIN_FACTORY(PauseMusicConfigFactory, registerPlugin<PauseMusicConfig>();)
+
+PauseMusicConfig::PauseMusicConfig(QWidget *parent, const QVariantList& args)
+    : KdeConnectPluginKcm(parent, args, QStringLiteral("kdeconnect_pausemusic_config"))
     , m_ui(new Ui::PauseMusicConfigUi())
-    , m_cfg(KSharedConfig::openConfig("kdeconnect/plugins/pausemusic"))
 {
     m_ui->setupUi(this);
 
     connect(m_ui->rad_ringing, SIGNAL(toggled(bool)), this, SLOT(changed()));
     connect(m_ui->rad_talking, SIGNAL(toggled(bool)), this, SLOT(changed()));
+    connect(m_ui->check_pause, SIGNAL(toggled(bool)), this, SLOT(changed()));
     connect(m_ui->check_mute, SIGNAL(toggled(bool)), this, SLOT(changed()));
 }
 
@@ -58,29 +52,28 @@ void PauseMusicConfig::defaults()
     Q_EMIT changed(true);
 }
 
-
 void PauseMusicConfig::load()
 {
     KCModule::load();
-    bool talking = m_cfg->group("condition").readEntry("talking_only", false);
+    bool talking = config()->get(QStringLiteral("conditionTalking"), false);
     m_ui->rad_talking->setChecked(talking);
     m_ui->rad_ringing->setChecked(!talking);
 
-    bool pause = m_cfg->group("actions").readEntry("pause", true);
-    bool mute = m_cfg->group("actions").readEntry("mute", false);
+    bool pause = config()->get(QStringLiteral("actionPause"), true);
+    bool mute = config()->get(QStringLiteral("actionMute"), false);
     m_ui->check_pause->setChecked(pause);
     m_ui->check_mute->setChecked(mute);
+
     Q_EMIT changed(false);
 }
 
-
 void PauseMusicConfig::save()
 {
-    m_cfg->group("condition").writeEntry("talking_only", m_ui->rad_talking->isChecked());
-    m_cfg->group("actions").writeEntry("pause", m_ui->check_pause->isChecked());
-    m_cfg->group("actions").writeEntry("mute", m_ui->check_mute->isChecked());
+    config()->set(QStringLiteral("conditionTalking"), m_ui->rad_talking->isChecked());
+    config()->set(QStringLiteral("actionPause"), m_ui->check_pause->isChecked());
+    config()->set(QStringLiteral("actionMute"), m_ui->check_mute->isChecked());
     KCModule::save();
-
     Q_EMIT changed(false);
 }
 
+#include "pausemusic_config.moc"
