@@ -21,45 +21,57 @@
 #include "pingplugin.h"
 
 #include <KNotification>
-#include <KIcon>
 #include <KLocalizedString>
+#include <KPluginFactory>
 
-#include <core/kdebugnamespace.h>
-#include <core/device.h>
+#include <QDebug>
 #include <QDBusConnection>
+#include <QLoggingCategory>
 
-K_PLUGIN_FACTORY( KdeConnectPluginFactory, registerPlugin< PingPlugin >(); )
-K_EXPORT_PLUGIN( KdeConnectPluginFactory("kdeconnect_ping", "kdeconnect-plugins") )
+#include <core/device.h>
+
+K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_ping.json", registerPlugin< PingPlugin >(); )
+
+Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_PING, "kdeconnect.plugin.ping")
 
 PingPlugin::PingPlugin(QObject* parent, const QVariantList& args)
     : KdeConnectPlugin(parent, args)
 {
-    //kDebug(debugArea()) << "Ping plugin constructor for device" << device()->name();
+//     qCDebug(KDECONNECT_PLUGIN_PING) << "Ping plugin constructor for device" << device()->name();
 }
 
 PingPlugin::~PingPlugin()
 {
-    //kDebug(debugArea()) << "Ping plugin destructor for device" << device()->name();
+//     qCDebug(KDECONNECT_PLUGIN_PING) << "Ping plugin destructor for device" << device()->name();
 }
 
 bool PingPlugin::receivePackage(const NetworkPackage& np)
 {
-    KNotification* notification = new KNotification("pingReceived"); //KNotification::Persistent
-    notification->setPixmap(KIcon("dialog-ok").pixmap(48, 48));
-    notification->setComponentData(KComponentData("kdeconnect", "kdeconnect-kded"));
+    KNotification* notification = new KNotification(QStringLiteral("pingReceived")); //KNotification::Persistent
+    notification->setIconName(QStringLiteral("dialog-ok"));
+    notification->setComponentName(QStringLiteral("kdeconnect"));
     notification->setTitle(device()->name());
-    notification->setText(np.get<QString>("message",i18n("Ping!"))); //This can be a source of spam
+    notification->setText(np.get<QString>(QStringLiteral("message"),i18n("Ping!"))); //This can be a source of spam
     notification->sendEvent();
 
     return true;
-
 }
 
 void PingPlugin::sendPing()
 {
     NetworkPackage np(PACKAGE_TYPE_PING);
     bool success = sendPackage(np);
-    kDebug(debugArea()) << "sendPing:" << success;
+    qCDebug(KDECONNECT_PLUGIN_PING) << "sendPing:" << success;
+}
+
+void PingPlugin::sendPing(const QString& customMessage)
+{
+    NetworkPackage np(PACKAGE_TYPE_PING);
+    if (!customMessage.isEmpty()) {
+        np.set(QStringLiteral("message"), customMessage);
+    }
+    bool success = sendPackage(np);
+    qCDebug(KDECONNECT_PLUGIN_PING) << "sendPing:" << success;
 }
 
 void PingPlugin::connected()
@@ -71,3 +83,6 @@ QString PingPlugin::dbusPath() const
 {
     return "/modules/kdeconnect/devices/" + device()->id() + "/ping";
 }
+
+#include "pingplugin.moc"
+
