@@ -35,23 +35,23 @@ Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_TELEPHONY, "kdeconnect.plugin.telephony")
 
 TelephonyPlugin::TelephonyPlugin(QObject *parent, const QVariantList &args)
     : KdeConnectPlugin(parent, args)
-    , m_telepathyInterface("org.freedesktop.Telepathy.ConnectionManager.kdeconnect", "/kdeconnect")
+    , m_telepathyInterface(QStringLiteral("org.freedesktop.Telepathy.ConnectionManager.kdeconnect"), QStringLiteral("/kdeconnect"))
 {
     connect(&m_telepathyInterface, SIGNAL(messageReceived(QString,QString)), SLOT(sendSms(QString,QString)));
 }
 
 KNotification* TelephonyPlugin::createNotification(const NetworkPackage& np)
 {
-    const QString event = np.get<QString>("event");
-    const QString phoneNumber = np.get<QString>("phoneNumber", i18n("unknown number"));
-    const QString contactName = np.get<QString>("contactName", phoneNumber);
-    const QByteArray phoneThumbnail = QByteArray::fromBase64(np.get<QByteArray>("phoneThumbnail", ""));
+    const QString event = np.get<QString>(QStringLiteral("event"));
+    const QString phoneNumber = np.get<QString>(QStringLiteral("phoneNumber"), i18n("unknown number"));
+    const QString contactName = np.get<QString>(QStringLiteral("contactName"), phoneNumber);
+    const QByteArray phoneThumbnail = QByteArray::fromBase64(np.get<QByteArray>(QStringLiteral("phoneThumbnail"), ""));
 
     // In case telepathy can handle the message, don't do anything else
     if (event == QLatin1String("sms") && m_telepathyInterface.isValid()) {
         qCDebug(KDECONNECT_PLUGIN_TELEPHONY) << "Passing a text message to the telepathy interface";
-        const QString messageBody = np.get<QString>("messageBody","");
-        QDBusReply<bool> reply = m_telepathyInterface.call("sendMessage", phoneNumber, contactName, messageBody);
+        const QString messageBody = np.get<QString>(QStringLiteral("messageBody"),QLatin1String(""));
+        QDBusReply<bool> reply = m_telepathyInterface.call(QStringLiteral("sendMessage"), phoneNumber, contactName, messageBody);
         if (reply) {
             return nullptr;
         } else {
@@ -64,22 +64,22 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPackage& np)
 
     const QString title = device()->name();
 
-    if (event == "ringing") {
+    if (event == QLatin1String("ringing")) {
         type = QStringLiteral("callReceived");
         icon = QStringLiteral("call-start");
         content = i18n("Incoming call from %1", contactName);
-    } else if (event == "missedCall") {
+    } else if (event == QLatin1String("missedCall")) {
         type = QStringLiteral("missedCall");
         icon = QStringLiteral("call-start");
         content = i18n("Missed call from %1", contactName);
         flags |= KNotification::Persistent;
-    } else if (event == "sms") {
+    } else if (event == QLatin1String("sms")) {
         type = QStringLiteral("smsReceived");
         icon = QStringLiteral("mail-receive");
-        QString messageBody = np.get<QString>("messageBody", "");
+        QString messageBody = np.get<QString>(QStringLiteral("messageBody"), QLatin1String(""));
         content = i18n("SMS from %1<br>%2", contactName, messageBody);
         flags |= KNotification::Persistent;
-    } else if (event == "talking") {
+    } else if (event == QLatin1String("talking")) {
         return nullptr;
     } else {
 #ifndef NDEBUG
@@ -101,7 +101,7 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPackage& np)
     } else {
         notification->setIconName(icon);
     }
-    notification->setComponentName("kdeconnect");
+    notification->setComponentName(QStringLiteral("kdeconnect"));
     notification->setTitle(title);
     notification->setText(content);
 
@@ -109,7 +109,7 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPackage& np)
         notification->setActions( QStringList(i18n("Mute Call")) );
         connect(notification, &KNotification::action1Activated, this, &TelephonyPlugin::sendMutePackage);
     } else if (event == QLatin1String("sms")) {
-        const QString messageBody = np.get<QString>("messageBody","");
+        const QString messageBody = np.get<QString>(QStringLiteral("messageBody"),QLatin1String(""));
         notification->setActions( QStringList(i18n("Reply")) );
         notification->setProperty("phoneNumber", phoneNumber);
         notification->setProperty("contactName", contactName);
@@ -123,7 +123,7 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPackage& np)
 
 bool TelephonyPlugin::receivePackage(const NetworkPackage& np)
 {
-    if (np.get<bool>("isCancel")) {
+    if (np.get<bool>(QStringLiteral("isCancel"))) {
 
         //TODO: Clear the old notification
         return true;
@@ -157,7 +157,7 @@ void TelephonyPlugin::showSendSmsDialog()
     QString contactName = sender()->property("contactName").toString();
     QString originalMessage = sender()->property("originalMessage").toString();
     SendSmsDialog* dialog = new SendSmsDialog(originalMessage, phoneNumber, contactName);
-    connect(dialog, SIGNAL(sendSms(QString,QString)), this, SLOT(sendSms(QString,QString)));
+    connect(dialog, &SendSmsDialog::sendSms, this, &TelephonyPlugin::sendSms);
     dialog->show();
 }
 
